pub enum ShellKind {
Posix,
Csh,
Tcsh,
Rc,
Fish,
PowerShell,
Pwsh,
Nushell,
Cmd,
Xonsh,
Elvish,
}Variants
Posix
Csh
Tcsh
Rc
Fish
PowerShell
Pre-installed “legacy” powershell for windows
Pwsh
PowerShell 7.x
Nushell
Cmd
Xonsh
Elvish
Implementations
Sourceimpl ShellKind
impl ShellKind
pub fn system() -> Self
pub fn new(program: impl AsRef<Path>, is_windows: bool) -> Self
pub fn to_shell_variable(self, input: &str) -> String
pub fn args_for_shell( &self, interactive: bool, combined_command: String, ) -> Vec<String>
pub const fn command_prefix(&self) -> Option<char>
pub fn prepend_command_prefix<'a>(&self, command: &'a str) -> Cow<'a, str>
pub const fn sequential_commands_separator(&self) -> char
pub const fn sequential_and_commands_separator(&self) -> &'static str
pub fn try_quote<'a>(&self, arg: &'a str) -> Option<Cow<'a, str>>
pub fn quote_powershell(arg: &str) -> Cow<'_, str>
pub fn quote_pwsh(arg: &str) -> Cow<'_, str>
pub fn quote_cmd(arg: &str) -> Cow<'_, str>
Sourcepub fn try_quote_prefix_aware<'a>(&self, arg: &'a str) -> Option<Cow<'a, str>>
pub fn try_quote_prefix_aware<'a>(&self, arg: &'a str) -> Option<Cow<'a, str>>
Quotes the given argument if necessary, taking into account the command prefix.
In other words, this will consider quoting arg without its command prefix to not break the command.
You should use this over try_quote when you want to quote a shell command.
pub fn split(&self, input: &str) -> Option<Vec<String>>
pub const fn activate_keyword(&self) -> &'static str
pub const fn clear_screen_command(&self) -> &'static str